Learn R Programming

ntwk (version 1.0.0)

lattice_network: Lattice/grid-like network with max degree of four across all nodes.

Description

Lattice/grid-like network with max degree of four across all nodes.

Usage

lattice_network(d, theta_1, theta_2, directed = FALSE)

Arguments

d

Number of nodes.

theta_1

Off-diagonal value or network effect.

theta_2

Diagonal value or momentum effect.

directed

Boolean if lower triangular is the opposite to the upper triangular matrix.

Value

A d x d adjacency matrix of a lattice network.

Examples

Run this code
# NOT RUN {
d <- 10
theta_2 <- 2
theta_1 <- 1
lattice_network(d = d, theta_1 = theta_1, theta_2 = theta_2)
# }

Run the code above in your browser using DataLab