powered by
Lattice/grid-like network with max degree of four across all nodes.
lattice_network(d, theta_1, theta_2, directed = FALSE)
Number of nodes.
Off-diagonal value or network effect.
Diagonal value or momentum effect.
Boolean if lower triangular is the opposite to the upper triangular matrix.
A d x d adjacency matrix of a lattice network.
d x d
# NOT RUN { d <- 10 theta_2 <- 2 theta_1 <- 1 lattice_network(d = d, theta_1 = theta_1, theta_2 = theta_2) # }
Run the code above in your browser using DataLab